==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Offset/ts/Offset_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Offset</name>
    <message>
        <source>Distance:</source>
        <translation type="obsolete">Distanza:</translation>
    </message>
    <message>
        <source>Number:</source>
        <translation type="obsolete">Numero:</translation>
    </message>
    <message>
        <source>Choose line, arc or circle</source>
        <translation type="obsolete">Scegliere una linea, un arco o un cerchio</translation>
    </message>
    <message>
        <source>Para&amp;llel (with Distance)</source>
        <translation type="obsolete">Para&amp;llela (con la distanza)</translation>
    </message>
    <message>
        <location filename="../OffsetInit.js" line="+2"/>
        <source>Offset (with Distance)</source>
        <translation>Offset (con la distanza)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Offset line, arc, circle or ellipse</source>
        <translation>Offset linea, arco cerchio o ellisse</translation>
    </message>
    <message>
        <source>Draw parallel to existing line or concentric arc, circle</source>
        <translation type="vanished">Tracciare un parallelo ad una linea esistente o un arco o cerchio concentrico</translation>
    </message>
    <message>
        <location filename="../Offset.ui" line="+17"/>
        <source>&amp;Distance:</source>
        <translation>&amp;Distanza:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Number:</source>
        <translation>&amp;Numero:</translation>
    </message>
    <message>
        <source>Choose line, arc, circle, ellipse or spline</source>
        <translation type="vanished">Scegliere linea, arco, cerchio o ellisse</translation>
    </message>
    <message>
        <location filename="../Offset.js" line="+75"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation>Scegliere linea, arco, cerchio o ellisse</translation>
    </message>
    <message>
        <location line="+89"/>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translation>Raggio è sceso sotto 0,0 dopo %1 cerchi concentrico.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translation>Raggio è sceso sotto 0,0 dopo %1 archi concentrici.</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Offset/ts/Offset_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Offset</name>
    <message>
        <source>Distance:</source>
        <translation type="obsolete">Distanza:</translation>
    </message>
    <message>
        <source>Number:</source>
        <translation type="obsolete">Numero:</translation>
    </message>
    <message>
        <source>Choose line, arc or circle</source>
        <translation type="obsolete">Scegliere una linea, un arco o un cerchio</translation>
    </message>
    <message>
        <source>Para&amp;llel (with Distance)</source>
        <translation type="obsolete">Para&amp;llela (con la distanza)</translation>
    </message>
    <message>
        <location filename="../OffsetInit.js" line="+2"/>
        <source>Offset (with Distance)</source>
        <translation>Offset (con la distanza)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Offset line, arc, circle or ellipse</source>
        <translation>Offset linea, arco cerchio o ellisse</translation>
    </message>
    <message>
        <source>Draw parallel to existing line or concentric arc, circle</source>
        <translation type="vanished">Tracciare un parallelo ad una linea esistente o un arco o cerchio concentrico</translation>
    </message>
    <message>
        <location filename="../Offset.ui" line="+17"/>
        <source>&amp;Distance:</source>
        <translation>&amp;Distanza:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Number:</source>
        <translation>&amp;Numero:</translation>
    </message>
    <message>
        <source>Choose line, arc, circle, ellipse or spline</source>
        <translation type="vanished">Scegliere linea, arco, cerchio o ellisse</translation>
    </message>
    <message>
        <location filename="../Offset.js" line="+75"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation>Scegliere linea, arco, cerchio o ellisse</translation>
    </message>
    <message numerus="yes">
        <location line="+89"/>
        <source>Radius dropped below 0.0 after %n concentric circle(s).</source>
        <translation>
            <numerusform>Raggio è sceso sotto 0,0 dopo %n cerchio concentrico.</numerusform>
            <numerusform>Raggio è sceso sotto 0,0 dopo %n cerchi concentrico.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+3"/>
        <source>Radius dropped below 0.0 after %n concentric arc(s).</source>
        <translation>
            <numerusform>Raggio è sceso sotto 0,0 dopo %n arco concentrico.</numerusform>
            <numerusform>Raggio è sceso sotto 0,0 dopo %n archi concentrici.</numerusform>
        </translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translation type="vanished">Raggio è sceso sotto 0,0 dopo %1 cerchi concentrico.</translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translation type="vanished">Raggio è sceso sotto 0,0 dopo %1 archi concentrici.</translation>
    </message>
</context>
</TS>
